@@ -1,4 +1,4 @@
-from .Base import *
+from .Base import Base
 
 
 class Method(Base):
@@ -15,6 +15,7 @@ class Method(Base):
     PODIUMCADEAUKAART = 'podiumcadeaukaart'
     KBC = 'kbc'
     GIFTCARD = 'giftcard'
+    INGHOMEPAY = 'inghomepay'
 
     def getMinimumAmount(self):
         if not self['amount'] or 'minimum' not in self['amount']:
